==> v1.3.1.tar.gz: framework/extensions/lock/src/Post/DiscussionLockedPost.php <==
<?php

/*
 * This file is part of Flarum.
 *
 * For detailed copyright and license information, please view the
 * LICENSE file that was distributed with this source code.
 */

namespace Flarum\Lock\Post;

use Flarum\Post\AbstractEventPost;
use Flarum\Post\MergeableInterface;
use Flarum\Post\Post;

class DiscussionLockedPost extends AbstractEventPost implements MergeableInterface
{
    /**
     * {@inheritdoc}
     */
    public static $type = 'discussionLocked';

    /**
     * {@inheritdoc}
     */
    public function saveAfter(Post $previous = null)
    {
        // If the previous post is another 'discussion locked' post, and it's
        // by the same user, then we can merge this post into it. If we find
        // that we've in fact reverted the locked status, delete it. Otherwise,
        // update its content.
        if ($previous instanceof static && $this->user_id === $previous->user_id) {
            if ($previous->content['locked'] != $this->content['locked']) {
                $previous->delete();
            } else {
                $previous->content = $this->content;

                $previous->save();
            }

            return $previous;
        }

        $this->save();

        return $this;
    }

    /**
     * Create a new instance in reply to a discussion.
     *
     * @param int $discussionId
     * @param int $userId
     * @param bool $isLocked
     * @return static
     */
    public static function reply($discussionId, $userId, $isLocked)
    {
        $post = new static;

        $post->content = static::buildContent($isLocked);
        $post->created_at = time();
        $post->discussion_id = $discussionId;
        $post->user_id = $userId;

        return $post;
    }

    /**
     * Build the content attribute.
     *
     * @param bool $isLocked Whether or not the discussion is locked.
     * @return array
     */
    public static function buildContent($isLocked)
    {
        return ['locked' => (bool) $isLocked];
    }
}

==> v1.8.7.tar.gz: framework/extensions/lock/src/Post/DiscussionLockedPost.php <==
<?php

/*
 * This file is part of Flarum.
 *
 * For detailed copyright and license information, please view the
 * LICENSE file that was distributed with this source code.
 */

namespace Flarum\Lock\Post;

use Carbon\Carbon;
use Flarum\Post\AbstractEventPost;
use Flarum\Post\MergeableInterface;
use Flarum\Post\Post;

class DiscussionLockedPost extends AbstractEventPost implements MergeableInterface
{
    /**
     * {@inheritdoc}
     */
    public static $type = 'discussionLocked';

    /**
     * {@inheritdoc}
     */
    public function saveAfter(Post $previous = null)
    {
        // If the previous post is another 'discussion locked' post, and it's
        // by the same user, then we can merge this post into it. If we find
        // that we've in fact reverted the locked status, delete it. Otherwise,
        // update its content.
        if ($previous instanceof static && $this->user_id === $previous->user_id) {
            if ($previous->content['locked'] != $this->content['locked']) {
                $previous->delete();
            } else {
                $previous->content = $this->content;

                $previous->save();
            }

            return $previous;
        }

        $this->save();

        return $this;
    }

    /**
     * Create a new instance in reply to a discussion.
     *
     * @param int $discussionId
     * @param int $userId
     * @param bool $isLocked
     * @return static
     */
    public static function reply($discussionId, $userId, $isLocked)
    {
        $post = new static;

        $post->content = static::buildContent($isLocked);
        $post->created_at = Carbon::now();
        $post->discussion_id = $discussionId;
        $post->user_id = $userId;

        return $post;
    }

    /**
     * Build the content attribute.
     *
     * @param bool $isLocked Whether or not the discussion is locked.
     * @return array
     */
    public static function buildContent($isLocked)
    {
        return ['locked' => (bool) $isLocked];
    }
}
